#! /usr/bin/env bash
make

EXEC_DRAIN=./drain
EXEC_SPOUT=./spout
EXEC_QPIDD=$(which qpidd)
EXEC_QPID_CONFIG=$(which qpid-config)
EXEC_QPID_ROUTE=$(which qpid-route)
EXEC_QPID_STAT=$(which qpid-stat)

if [[ -x ${EXEC_DRAIN} && -x ${EXEC_SPOUT} ]] ; then
    echo "STARTING BROKERS"
else
    echo "${EXEC_DRAIN} ${EXEC_SPOUT} NOT EXECUTABLE" 
    exit 1
fi

STORE_GLOB=$(mktemp -d)
mkdir ${STORE_GLOB}/B1
mkdir ${STORE_GLOB}/B2

B1=$(${EXEC_QPIDD} --auth no --store-dir ${STORE_GLOB}/B1 --no-data-dir --port 0 --daemon --log-enable debug --log-to-file B1.log)
B2=$(${EXEC_QPIDD} --auth no --store-dir ${STORE_GLOB}/B2 --no-data-dir --port 0 --daemon --log-enable debug --log-to-file B2.log)


set -x
${EXEC_QPID_CONFIG} -a localhost:$B1 add exchange xml xml
${EXEC_QPID_CONFIG} -a localhost:$B2 add exchange xml xml


if [[ $1 =~ route ]] ; then
    ${EXEC_QPID_ROUTE} route add localhost:$B2 localhost:$B1 xml weather
else
    ${EXEC_QPID_ROUTE} dynamic add localhost:$B2 localhost:$B1 xml
fi

sleep 5
set +x
echo "RUNNING DRAIN"
${EXEC_DRAIN} -b localhost:$B2 -t 50 "xml; {node:{type:topic}, link:{x-bindings:[{key:'weather', arguments:{xquery:\"$(cat rdu.xquery )\"}}]}}" &

#${EXEC_DRAIN} -b localhost:$B1 -t 50 "xml; {node:{type:topic}, link:{x-bindings:[{key:'weather', arguments:{xquery:\"$(cat rdu.xquery )\"}}]}}" &

sleep 5
 
echo "RUNNING SPOUT"
echo " VVV MESSAGE VVV " 
${EXEC_SPOUT} -b localhost:$B1 --content "$(cat rdu.xml)" xml/weather
sleep 2
echo " ^^^ MESSAGE ^^^ " 
${EXEC_QPID_STAT} localhost:$B1 -e | grep -P '(xml|msgOut)'
${EXEC_QPID_STAT} localhost:$B2 -e | grep xml

rm -rf ${STORE_GLOB}
{
killall -9 drain
killall -9 qpidd
} &>/dev/null
